@@ -11,7 +11,7 @@ package Term::ANSIEncode;
 #                     Written By Richard Kelsch                       #
 #                  © Copyright 2025 Richard Kelsch                    #
 #                        All Rights Reserved                          #
-#                           Version 1.12                              #
+#                           Version 1.13                              #
 #######################################################################
 # This program is free software: you can redistribute it and/or       #
 # modify it under the terms of the GNU General Public License as      #
@@ -45,7 +45,7 @@ use constant {
 binmode(STDOUT, ":encoding(UTF-8)");
 
 BEGIN {
-    our $VERSION = '1.12';
+    our $VERSION = '1.13';
 }
 
 sub ansi_output {
@@ -221,12 +221,24 @@ sub new {
 		$finish = 0x2B59;
 	}
 
+	my $name = charnames::viacode(0x1F341); # Maple Leaf
+	$self->{'characters'}->{$name} = charnames::string_vianame($name);
     foreach my $u ($start .. $finish) {
-        my $name = charnames::viacode($u);
+        $name = charnames::viacode($u);
         unless ($name =~ /^(ZERO|LINE SEPARATOR|LEFT-TO-RIGHT|PARAGRAPH|POP |RIGHT-TO-LEFT|TRIGRAM|BRAILLE)/) {
             $self->{'characters'}->{$name} = charnames::string_vianame($name);
         }
-    } ## end foreach my $u (0x2000 .. 0x2B59)
+    }
+	if ($self->{'mode'} =~ /full|long/i) {
+		$start = 0x1F300;
+		$finish = 0x1FBFF;
+		foreach my $u ($start .. $finish) {
+			$name = charnames::viacode($u);
+			unless ($name =~ /^(ZERO|LINE SEPARATOR|LEFT-TO-RIGHT|PARAGRAPH|POP |RIGHT-TO-LEFT|TRIGRAM|BRAILLE)/) {
+				$self->{'characters'}->{$name} = charnames::string_vianame($name);
+			}
+		}
+	}
     bless($self, $class);
     return ($self);
 } ## end sub new
